==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/loader/PopulationLoader.java <==
package io.ciera.tool.sql.loader;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.file.GeneralFile;
import io.ciera.tool.sql.associationserializerloader.AssociationSerializerLoader;
import io.ciera.tool.sql.associationserializerloader.AssociationSerializerLoaderSet;
import io.ciera.tool.sql.loader.BatchRelator;
import io.ciera.tool.sql.loader.BatchRelatorSet;
import io.ciera.tool.sql.loader.InstanceLoader;
import io.ciera.tool.sql.loader.InstanceLoaderSet;
import io.ciera.tool.sql.loader.InstanceSerializer;
import io.ciera.tool.sql.loader.InstanceSerializerSet;


public interface PopulationLoader extends IModelInstance<PopulationLoader,Sql> {

    // attributes
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public String getPackage() throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public void setComp_name( String m_comp_name ) throws XtumlException;
    public String getComp_name() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void addR3001_serializes_population_using_InstanceSerializer( InstanceSerializer inst ) {}
    default public void removeR3001_serializes_population_using_InstanceSerializer( InstanceSerializer inst ) {}
    public InstanceSerializerSet R3001_serializes_population_using_InstanceSerializer() throws XtumlException;
    default public void addR3005_loads_population_using_InstanceLoader( InstanceLoader inst ) {}
    default public void removeR3005_loads_population_using_InstanceLoader( InstanceLoader inst ) {}
    public InstanceLoaderSet R3005_loads_population_using_InstanceLoader() throws XtumlException;
    default public void setR3009_is_a_GeneralFile( GeneralFile inst ) {}
    public GeneralFile R3009_is_a_GeneralFile() throws XtumlException;
    default public void addR3011_relates_instances_using_BatchRelator( BatchRelator inst ) {}
    default public void removeR3011_relates_instances_using_BatchRelator( BatchRelator inst ) {}
    public BatchRelatorSet R3011_relates_instances_using_BatchRelator() throws XtumlException;
    default public void addR3019_renders_association_serializer_loaders_with_AssociationSerializerLoader( AssociationSerializerLoader inst ) {}
    default public void removeR3019_renders_association_serializer_loaders_with_AssociationSerializerLoader( AssociationSerializerLoader inst ) {}
    public AssociationSerializerLoaderSet R3019_renders_association_serializer_loaders_with_AssociationSerializerLoader() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/loader/PopulationLoader.java <==
package io.ciera.tool.sql.loader;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.file.GeneralFile;
import io.ciera.tool.sql.loader.BatchRelator;
import io.ciera.tool.sql.loader.BatchRelatorSet;
import io.ciera.tool.sql.loader.InstanceLoader;
import io.ciera.tool.sql.loader.InstanceLoaderSet;
import io.ciera.tool.sql.loader.InstanceSerializer;
import io.ciera.tool.sql.loader.InstanceSerializerSet;
import io.ciera.tool.sql.loader.associationserializerloader.AssociationSerializerLoader;
import io.ciera.tool.sql.loader.associationserializerloader.AssociationSerializerLoaderSet;


public interface PopulationLoader extends IModelInstance<PopulationLoader,Sql> {

    // attributes
    public String getName() throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public String getPackage() throws XtumlException;
    public String getComp_name() throws XtumlException;
    public void setComp_name( String m_comp_name ) throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void addR3001_serializes_population_using_InstanceSerializer( InstanceSerializer inst ) {}
    default public void removeR3001_serializes_population_using_InstanceSerializer( InstanceSerializer inst ) {}
    public InstanceSerializerSet R3001_serializes_population_using_InstanceSerializer() throws XtumlException;
    default public void addR3005_loads_population_using_InstanceLoader( InstanceLoader inst ) {}
    default public void removeR3005_loads_population_using_InstanceLoader( InstanceLoader inst ) {}
    public InstanceLoaderSet R3005_loads_population_using_InstanceLoader() throws XtumlException;
    default public void setR3009_GeneralFile( GeneralFile inst ) {}
    public GeneralFile R3009_GeneralFile() throws XtumlException;
    default public void addR3011_relates_instances_using_BatchRelator( BatchRelator inst ) {}
    default public void removeR3011_relates_instances_using_BatchRelator( BatchRelator inst ) {}
    public BatchRelatorSet R3011_relates_instances_using_BatchRelator() throws XtumlException;
    default public void addR3019_renders_association_serializer_loaders_with_AssociationSerializerLoader( AssociationSerializerLoader inst ) {}
    default public void removeR3019_renders_association_serializer_loaders_with_AssociationSerializerLoader( AssociationSerializerLoader inst ) {}
    public AssociationSerializerLoaderSet R3019_renders_association_serializer_loaders_with_AssociationSerializerLoader() throws XtumlException;


}
